emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] Changes to emacs/lisp/vc-git.el,v


From: Eric S. Raymond
Subject: [Emacs-diffs] Changes to emacs/lisp/vc-git.el,v
Date: Thu, 15 May 2008 17:39:06 +0000

CVSROOT:        /sources/emacs
Module name:    emacs
Changes by:     Eric S. Raymond <esr>   08/05/15 17:38:51

Index: lisp/vc-git.el
===================================================================
RCS file: /sources/emacs/emacs/lisp/vc-git.el,v
retrieving revision 1.63
retrieving revision 1.64
diff -u -b -r1.63 -r1.64
--- lisp/vc-git.el      10 May 2008 13:27:15 -0000      1.63
+++ lisp/vc-git.el      15 May 2008 17:38:46 -0000      1.64
@@ -69,10 +69,12 @@
 ;; * checkout (file &optional editable rev)       OK
 ;; * revert (file &optional contents-done)        OK
 ;; - rollback (files)                             COULD BE SUPPORTED
-;; - merge (file rev1 rev2)                       It would be possible to 
merge changes into
-;;                                                 a single file, but when 
committing they
-;;                                                 wouldn't be identified as a 
merge by git,
-;;                                                 so it's probably not a good 
idea.
+;; - merge (file rev1 rev2)                   It would be possible to merge
+;;                                          changes into a single file, but 
when
+;;                                          committing they wouldn't
+;;                                          be identified as a merge
+;;                                          by git, so it's probably
+;;                                          not a good idea.
 ;; - merge-news (file)                            see `merge'
 ;; - steal-lock (file &optional revision)         NOT NEEDED
 ;; HISTORY FUNCTIONS
@@ -87,10 +89,9 @@
 ;; - annotate-time ()                             OK
 ;; - annotate-current-time ()                     NOT NEEDED
 ;; - annotate-extract-revision-at-line ()         OK
 ;; SNAPSHOT SYSTEM
 ;; - create-snapshot (dir name branchp)                   OK
 ;; - assign-name (file name)                      NOT NEEDED
 ;; - retrieve-snapshot (dir name update)          OK, needs to update buffers
 ;; MISCELLANEOUS
 ;; - make-version-backups-p (file)                NOT NEEDED
 ;; - repository-hostname (dirname)                NOT NEEDED
@@ -554,16 +555,16 @@
     (and (looking-at "[0-9a-f^][0-9a-f]+")
          (buffer-substring-no-properties (match-beginning 0) (match-end 0)))))
 
-;;; SNAPSHOT SYSTEM
+;;; TAG SYSTEM
 
-(defun vc-git-create-snapshot (dir name branchp)
+(defun vc-git-create-tag (dir name branchp)
   (let ((default-directory dir))
     (and (vc-git-command nil 0 nil "update-index" "--refresh")
          (if branchp
              (vc-git-command nil 0 nil "checkout" "-b" name)
            (vc-git-command nil 0 nil "tag" name)))))
 
-(defun vc-git-retrieve-snapshot (dir name update)
+(defun vc-git-retrieve-tag (dir name update)
   (let ((default-directory dir))
     (vc-git-command nil 0 nil "checkout" name)
     ;; FIXME: update buffers if `update' is true
@@ -87,10 +89,9 @@
 ;; - annotate-current-time ()                     NOT NEEDED
 ;; - annotate-extract-revision-at-line ()         OK
-;; SNAPSHOT SYSTEM
-;; - create-snapshot (dir name branchp)                   OK
-;; - assign-name (file name)                      NOT NEEDED
-;; - retrieve-snapshot (dir name update)          OK, needs to update buffers
+;; TAG SYSTEM
+;; - create-tag (dir name branchp)        OK
+;; - retrieve-tag (dir name update)       OK, needs to update buffers
 ;; MISCELLANEOUS
 ;; - make-version-backups-p (file)                NOT NEEDED




reply via email to

[Prev in Thread] Current Thread [Next in Thread]